@@ -1,6 +1,6 @@
 /* fieldlistview.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2008 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2002-2009 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -151,6 +151,8 @@ FieldListView::FieldListView( AGUIX *caguix, int cx, int cy, int cwidth, int che
   m_complete_update = false;
 
   gettimeofday( &m_last_update_time, NULL );
+
+  m_global_field_spacing = 0;
 }
 
 FieldListView::~FieldListView()
@@ -559,11 +561,7 @@ int FieldListView::getMaxTextWidth()
 
   wi = 0;
   for ( i = 0; i < fields; i++ ) {
-    if ( fieldwidth[i] < 0 ) {
-      wi += getUsedWidth( i );
-    } else {
-      wi += fieldwidth[i];
-    }
+      wi += getEffectiveFieldWidth( i );
   }
   return wi;
 }
@@ -623,6 +621,12 @@ void FieldListView::setFieldText( int field, const std::string nv )
   redraw();
 }
 
+std::string FieldListView::getFieldText( int field ) const
+{
+  if ( field < 0 || field >= fields ) return "";
+  return fieldtext[ field ];
+}
+
 void FieldListView::setFieldTextMergedQ( int field, bool nv )
 {
   if ( ( field < 0 ) || ( field >= fields ) ) return;
@@ -742,10 +746,7 @@ void FieldListView::redrawLine( int element )
   // is usually could for every visible line
   DrawableCont dc( _aguix, buffer );
   for ( f = 0; f < fields; f++ ) {
-    if ( fieldwidth[ f ] < 0)
-      ex = sx + getUsedWidth( f );
-    else
-      ex = sx + fieldwidth[ f ];
+    ex = sx + getEffectiveFieldWidth( f );
     
     if ( ( sx < ( xoffset + getInnerWidth() ) ) && ( ex > xoffset ) ) {
       // field visible
@@ -756,6 +757,7 @@ void FieldListView::redrawLine( int element )
       tx = ex - xoffset;
       if ( tx > getInnerWidth() ) tx = getInnerWidth();
       tx = tx + ox - clip_rect.x;
+      tx -= getFieldSpace( f ) / 2;
       if ( tx < 0 ) tx = 0;
       clip_rect.width = tx;
       
@@ -765,9 +767,11 @@ void FieldListView::redrawLine( int element )
 
       if ( fieldalign[ f ] == ALIGN_RIGHT ) {
 	int tw = _aguix->getTextWidth( s.c_str(), font );
-	_aguix->DrawText( dc, font, s.c_str(), ox + ex - xoffset - tw, vis * elementHeight + oy, tfg );
+        int spacing = getFieldSpace( f ) / 2;
+	_aguix->DrawText( dc, font, s.c_str(), ox + ex - spacing - xoffset - tw, vis * elementHeight + oy, tfg );
       } else {
-	_aguix->DrawText( dc, font, s.c_str(), ox + sx - xoffset, vis * elementHeight + oy, tfg );
+        int spacing = getFieldSpace( f ) / 2;
+        _aguix->DrawText( dc, font, s.c_str(), ox + sx + spacing - xoffset, vis * elementHeight + oy, tfg );
       }
     }
     
@@ -2980,10 +2984,7 @@ void FieldListView::redrawHeader()
     fakefield = f;
     ex = sx;
     for (;;) {
-      if ( fieldwidth[ fakefield ] < 0)
-	ex += getUsedWidth( fakefield );
-      else
-	ex += fieldwidth[ fakefield ];
+      ex += getEffectiveFieldWidth( fakefield );
       if ( fieldtextmerged[ fakefield ] == false ) break;
       if ( ( fakefield + 1 ) >= fields ) break;
       fakefield++;
@@ -3142,10 +3143,7 @@ int FieldListView::getFieldForPoint( int mx, int my, int *start_x, int *end_x )
     fakefield = f;
     ex = sx;
     for (;;) {
-      if ( fieldwidth[ fakefield ] < 0)
-	ex += getUsedWidth( fakefield );
-      else
-	ex += fieldwidth[ fakefield ];
+      ex += getEffectiveFieldWidth( fakefield );
       if ( fieldtextmerged[ fakefield ] == false ) break;
       if ( ( fakefield + 1 ) >= fields ) break;
       fakefield++;
@@ -3237,11 +3235,7 @@ void FieldListView::handleHeader( Message *msg )
 	  drag_base_x = mx;
 	  
 	  resizeable_f = findResizeableField( drag_field );
-	  if ( fieldwidth[resizeable_f] < 0 ) {
-	    drag_base_w = getUsedWidth( resizeable_f );
-	  } else {
-	    drag_base_w = fieldwidth[resizeable_f];
-	  }
+          drag_base_w = getEffectiveFieldWidth( resizeable_f );
 	  
 	  // grab pointer to receive motion events
 	  grabs = XGrabPointer( _aguix->getDisplay(),
@@ -3274,6 +3268,7 @@ void FieldListView::handleHeader( Message *msg )
     mx = mx - ox + xoffset;
     
     int nw = drag_base_w + ( mx - drag_base_x );
+    nw -= getFieldSpace( drag_field );
     if ( nw < 0 ) nw = 0;
 
     resizeable_f = findResizeableField( drag_field );
@@ -3473,10 +3468,7 @@ int FieldListView::getLastField( int *start_x, int *end_x )
     fakefield = f;
     ex = sx;
     for (;;) {
-      if ( fieldwidth[ fakefield ] < 0)
-	ex += getUsedWidth( fakefield );
-      else
-	ex += fieldwidth[ fakefield ];
+      ex += getEffectiveFieldWidth( fakefield );
       if ( fieldtextmerged[ fakefield ] == false ) break;
       if ( ( fakefield + 1 ) >= fields ) break;
       fakefield++;
@@ -3530,13 +3522,13 @@ int FieldListView::getFieldWidth( int field ) const
   return fieldwidth[ field ];
 }
 
-int FieldListView::getUsedFieldWidth( int field )
+int FieldListView::getEffectiveFieldWidth( int field )
 {
-  if ( field < 0 || field >= fields ) return 0;
-  if ( fieldwidth[ field ] < 0)
-    return getUsedWidth( field );
-  else
-    return fieldwidth[ field ];
+    if ( field < 0 || field >= fields ) return 0;
+    if ( fieldwidth[ field ] < 0 )
+        return getUsedWidth( field ) + getFieldSpace( field );
+    else
+        return fieldwidth[ field ] + getFieldSpace( field );
 }
 
 int FieldListView::changeButtonFunction( buttonfunction_t bf, int button, int mod )
@@ -3782,3 +3774,15 @@ void FieldListView::timeLimitedRedraw()
         m_last_update_time = now;
     }
 }
+
+void FieldListView::setGlobalFieldSpace( int spacing )
+{
+    if ( spacing >= 0 ) {
+        m_global_field_spacing = spacing;
+    }
+}
+
+int FieldListView::getFieldSpace( int field ) const
+{
+    return m_global_field_spacing;
+}
