@@ -1,6 +1,6 @@
 /* util.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2007 Ralf Hoffmann.
+ * Copyright (C) 2001-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -29,13 +29,16 @@ int createLines(const char*,char ***);
 
 namespace AGUIXUtils
 {
-    std::string bytes_to_human_readable( loff_t number );
+    std::string bytes_to_human_readable( loff_t number,
+                                         int threshold = 1);
 
     std::string tolower( const std::string &str );
     
     bool stringIsShorter( const char *str, int len );
 
     std::string formatStringToString( const char *format, ... );
+
+    loff_t convertHumanStringToNumber( const std::string &str );
 }
 
 #endif
