@@ -1,6 +1,6 @@
 /* basic_actions.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2007 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -25,6 +25,7 @@
 #include "worker.h"
 #include "wcfiletype.hh"
 #include "fileentry.hh"
+#include "nmspecialsourceext.hh"
 
 /***********
   DNDAction
