@@ -280,92 +280,95 @@
      LAYOUT_WCP = 506,
      BUTTONSVERT_WCP = 507,
      LISTVIEWSVERT_WCP = 508,
-     EXTCOND_WCP = 509,
-     USEEXTCOND_WCP = 510,
-     SUBTYPE_WCP = 511,
-     PARENTACTIONOP_WCP = 512,
-     NOOPERATIONOP_WCP = 513,
-     COLORMODE_WCP = 514,
-     DEFAULT_WCP = 515,
-     CUSTOM_WCP = 516,
-     UNSELECTCOLOR_WCP = 517,
-     SELECTCOLOR_WCP = 518,
-     UNSELECTACTIVECOLOR_WCP = 519,
-     SELECTACTIVECOLOR_WCP = 520,
-     COLOREXTERNPROG_WCP = 521,
-     PARENT_WCP = 522,
-     DONTCD_WCP = 523,
-     DONTCHECKVIRTUAL_WCP = 524,
-     GOFTPOP_WCP = 525,
-     HOSTNAME_WCP = 526,
-     USERNAME_WCP = 527,
-     PASSWORD_WCP = 528,
-     DONTENTERFTP_WCP = 529,
-     ALWAYSSTOREPW_WCP = 530,
-     INTERNALVIEWOP_WCP = 531,
-     CUSTOMFILES_WCP = 532,
-     SHOWMODE_WCP = 533,
-     SELECTED_WCP = 534,
-     REVERSESEARCH_WCP = 535,
-     MOUSECONF_WCP = 536,
-     SELECTBUTTON_WCP = 537,
-     ACTIVATEBUTTON_WCP = 538,
-     SCROLLBUTTON_WCP = 539,
-     SELECTMETHOD_WCP = 540,
-     ALTERNATIVE_WCP = 541,
-     SEARCHOP_WCP = 542,
-     EDITCOMMAND_WCP = 543,
-     SHOWPREVRESULTS_WCP = 544,
-     TEXTVIEW_WCP = 545,
-     TEXTVIEWHIGHLIGHTED_WCP = 546,
-     TEXTVIEWSELECTION_WCP = 547,
-     DIRBOOKMARKOP_WCP = 548,
-     OPENCONTEXTMENUOP_WCP = 549,
-     RUNCUSTOMACTION_WCP = 550,
-     CUSTOMNAME_WCP = 551,
-     CONTEXTBUTTON_WCP = 552,
-     ACTIVATEMOD_WCP = 553,
-     SCROLLMOD_WCP = 554,
-     CONTEXTMOD_WCP = 555,
-     NONE_WCP = 556,
-     CUSTOMACTION_WCP = 557,
-     SAVE_WORKER_STATE_ON_EXIT_WCP = 558,
-     OPENWORKERMENUOP_WCP = 559,
-     CHANGELABELOP_WCP = 560,
-     ASKFORLABEL_WCP = 561,
-     LABELCOLORS_WCP = 562,
-     BOOKMARKLABEL_WCP = 563,
-     BOOKMARKFILTER_WCP = 564,
-     SHOWONLYBOOKMARKS_WCP = 565,
-     SHOWONLYLABEL_WCP = 566,
-     SHOWALL_WCP = 567,
-     OPTIONMODE_WCP = 568,
-     INVERT_WCP = 569,
-     SET_WCP = 570,
-     CHANGEFILTERS_WCP = 571,
-     CHANGEBOOKMARKS_WCP = 572,
-     QUERYLABEL_WCP = 573,
-     MODIFYTABSOP_WCP = 574,
-     TABACTION_WCP = 575,
-     NEWTAB_WCP = 576,
-     CLOSECURRENTTAB_WCP = 577,
-     NEXTTAB_WCP = 578,
-     PREVTAB_WCP = 579,
-     ERROR = 580,
-     ACTIVESIDE_WCP = 581,
-     SHOWFREESPACE_WCP = 582,
-     ACTIVEMODE_WCP = 583,
-     ASK_WCP = 584,
-     SSHALLOW_WCP = 585,
-     FIELD_WIDTH_WCP = 586,
-     QUICKSEARCHENABLED_WCP = 587,
-     FILTEREDSEARCHENABLED_WCP = 588,
-     XFTFONTS_WCP = 589,
-     USEMAGIC_WCP = 590,
-     MAGICPATTERN_WCP = 591,
-     MAGICCOMPRESSED_WCP = 592,
-     STRING_WCP = 593,
-     NUM_WCP = 594
+     LISTVIEWWEIGHT_WCP = 509,
+     EXTCOND_WCP = 510,
+     USEEXTCOND_WCP = 511,
+     SUBTYPE_WCP = 512,
+     PARENTACTIONOP_WCP = 513,
+     NOOPERATIONOP_WCP = 514,
+     COLORMODE_WCP = 515,
+     DEFAULT_WCP = 516,
+     CUSTOM_WCP = 517,
+     UNSELECTCOLOR_WCP = 518,
+     SELECTCOLOR_WCP = 519,
+     UNSELECTACTIVECOLOR_WCP = 520,
+     SELECTACTIVECOLOR_WCP = 521,
+     COLOREXTERNPROG_WCP = 522,
+     PARENT_WCP = 523,
+     DONTCD_WCP = 524,
+     DONTCHECKVIRTUAL_WCP = 525,
+     GOFTPOP_WCP = 526,
+     HOSTNAME_WCP = 527,
+     USERNAME_WCP = 528,
+     PASSWORD_WCP = 529,
+     DONTENTERFTP_WCP = 530,
+     ALWAYSSTOREPW_WCP = 531,
+     INTERNALVIEWOP_WCP = 532,
+     CUSTOMFILES_WCP = 533,
+     SHOWMODE_WCP = 534,
+     SELECTED_WCP = 535,
+     REVERSESEARCH_WCP = 536,
+     MOUSECONF_WCP = 537,
+     SELECTBUTTON_WCP = 538,
+     ACTIVATEBUTTON_WCP = 539,
+     SCROLLBUTTON_WCP = 540,
+     SELECTMETHOD_WCP = 541,
+     ALTERNATIVE_WCP = 542,
+     SEARCHOP_WCP = 543,
+     EDITCOMMAND_WCP = 544,
+     SHOWPREVRESULTS_WCP = 545,
+     TEXTVIEW_WCP = 546,
+     TEXTVIEWHIGHLIGHTED_WCP = 547,
+     TEXTVIEWSELECTION_WCP = 548,
+     DIRBOOKMARKOP_WCP = 549,
+     OPENCONTEXTMENUOP_WCP = 550,
+     RUNCUSTOMACTION_WCP = 551,
+     CUSTOMNAME_WCP = 552,
+     CONTEXTBUTTON_WCP = 553,
+     ACTIVATEMOD_WCP = 554,
+     SCROLLMOD_WCP = 555,
+     CONTEXTMOD_WCP = 556,
+     NONE_WCP = 557,
+     CUSTOMACTION_WCP = 558,
+     SAVE_WORKER_STATE_ON_EXIT_WCP = 559,
+     OPENWORKERMENUOP_WCP = 560,
+     CHANGELABELOP_WCP = 561,
+     ASKFORLABEL_WCP = 562,
+     LABELCOLORS_WCP = 563,
+     BOOKMARKLABEL_WCP = 564,
+     BOOKMARKFILTER_WCP = 565,
+     SHOWONLYBOOKMARKS_WCP = 566,
+     SHOWONLYLABEL_WCP = 567,
+     SHOWALL_WCP = 568,
+     OPTIONMODE_WCP = 569,
+     INVERT_WCP = 570,
+     SET_WCP = 571,
+     CHANGEFILTERS_WCP = 572,
+     CHANGEBOOKMARKS_WCP = 573,
+     QUERYLABEL_WCP = 574,
+     MODIFYTABSOP_WCP = 575,
+     TABACTION_WCP = 576,
+     NEWTAB_WCP = 577,
+     CLOSECURRENTTAB_WCP = 578,
+     NEXTTAB_WCP = 579,
+     PREVTAB_WCP = 580,
+     CHANGELAYOUTOP_WCP = 581,
+     INFIXSEARCH_WCP = 582,
+     ERROR = 583,
+     ACTIVESIDE_WCP = 584,
+     SHOWFREESPACE_WCP = 585,
+     ACTIVEMODE_WCP = 586,
+     ASK_WCP = 587,
+     SSHALLOW_WCP = 588,
+     FIELD_WIDTH_WCP = 589,
+     QUICKSEARCHENABLED_WCP = 590,
+     FILTEREDSEARCHENABLED_WCP = 591,
+     XFTFONTS_WCP = 592,
+     USEMAGIC_WCP = 593,
+     MAGICPATTERN_WCP = 594,
+     MAGICCOMPRESSED_WCP = 595,
+     STRING_WCP = 596,
+     NUM_WCP = 597
    };
 #endif
 /* Tokens.  */
@@ -620,104 +623,107 @@
 #define LAYOUT_WCP 506
 #define BUTTONSVERT_WCP 507
 #define LISTVIEWSVERT_WCP 508
-#define EXTCOND_WCP 509
-#define USEEXTCOND_WCP 510
-#define SUBTYPE_WCP 511
-#define PARENTACTIONOP_WCP 512
-#define NOOPERATIONOP_WCP 513
-#define COLORMODE_WCP 514
-#define DEFAULT_WCP 515
-#define CUSTOM_WCP 516
-#define UNSELECTCOLOR_WCP 517
-#define SELECTCOLOR_WCP 518
-#define UNSELECTACTIVECOLOR_WCP 519
-#define SELECTACTIVECOLOR_WCP 520
-#define COLOREXTERNPROG_WCP 521
-#define PARENT_WCP 522
-#define DONTCD_WCP 523
-#define DONTCHECKVIRTUAL_WCP 524
-#define GOFTPOP_WCP 525
-#define HOSTNAME_WCP 526
-#define USERNAME_WCP 527
-#define PASSWORD_WCP 528
-#define DONTENTERFTP_WCP 529
-#define ALWAYSSTOREPW_WCP 530
-#define INTERNALVIEWOP_WCP 531
-#define CUSTOMFILES_WCP 532
-#define SHOWMODE_WCP 533
-#define SELECTED_WCP 534
-#define REVERSESEARCH_WCP 535
-#define MOUSECONF_WCP 536
-#define SELECTBUTTON_WCP 537
-#define ACTIVATEBUTTON_WCP 538
-#define SCROLLBUTTON_WCP 539
-#define SELECTMETHOD_WCP 540
-#define ALTERNATIVE_WCP 541
-#define SEARCHOP_WCP 542
-#define EDITCOMMAND_WCP 543
-#define SHOWPREVRESULTS_WCP 544
-#define TEXTVIEW_WCP 545
-#define TEXTVIEWHIGHLIGHTED_WCP 546
-#define TEXTVIEWSELECTION_WCP 547
-#define DIRBOOKMARKOP_WCP 548
-#define OPENCONTEXTMENUOP_WCP 549
-#define RUNCUSTOMACTION_WCP 550
-#define CUSTOMNAME_WCP 551
-#define CONTEXTBUTTON_WCP 552
-#define ACTIVATEMOD_WCP 553
-#define SCROLLMOD_WCP 554
-#define CONTEXTMOD_WCP 555
-#define NONE_WCP 556
-#define CUSTOMACTION_WCP 557
-#define SAVE_WORKER_STATE_ON_EXIT_WCP 558
-#define OPENWORKERMENUOP_WCP 559
-#define CHANGELABELOP_WCP 560
-#define ASKFORLABEL_WCP 561
-#define LABELCOLORS_WCP 562
-#define BOOKMARKLABEL_WCP 563
-#define BOOKMARKFILTER_WCP 564
-#define SHOWONLYBOOKMARKS_WCP 565
-#define SHOWONLYLABEL_WCP 566
-#define SHOWALL_WCP 567
-#define OPTIONMODE_WCP 568
-#define INVERT_WCP 569
-#define SET_WCP 570
-#define CHANGEFILTERS_WCP 571
-#define CHANGEBOOKMARKS_WCP 572
-#define QUERYLABEL_WCP 573
-#define MODIFYTABSOP_WCP 574
-#define TABACTION_WCP 575
-#define NEWTAB_WCP 576
-#define CLOSECURRENTTAB_WCP 577
-#define NEXTTAB_WCP 578
-#define PREVTAB_WCP 579
-#define ERROR 580
-#define ACTIVESIDE_WCP 581
-#define SHOWFREESPACE_WCP 582
-#define ACTIVEMODE_WCP 583
-#define ASK_WCP 584
-#define SSHALLOW_WCP 585
-#define FIELD_WIDTH_WCP 586
-#define QUICKSEARCHENABLED_WCP 587
-#define FILTEREDSEARCHENABLED_WCP 588
-#define XFTFONTS_WCP 589
-#define USEMAGIC_WCP 590
-#define MAGICPATTERN_WCP 591
-#define MAGICCOMPRESSED_WCP 592
-#define STRING_WCP 593
-#define NUM_WCP 594
+#define LISTVIEWWEIGHT_WCP 509
+#define EXTCOND_WCP 510
+#define USEEXTCOND_WCP 511
+#define SUBTYPE_WCP 512
+#define PARENTACTIONOP_WCP 513
+#define NOOPERATIONOP_WCP 514
+#define COLORMODE_WCP 515
+#define DEFAULT_WCP 516
+#define CUSTOM_WCP 517
+#define UNSELECTCOLOR_WCP 518
+#define SELECTCOLOR_WCP 519
+#define UNSELECTACTIVECOLOR_WCP 520
+#define SELECTACTIVECOLOR_WCP 521
+#define COLOREXTERNPROG_WCP 522
+#define PARENT_WCP 523
+#define DONTCD_WCP 524
+#define DONTCHECKVIRTUAL_WCP 525
+#define GOFTPOP_WCP 526
+#define HOSTNAME_WCP 527
+#define USERNAME_WCP 528
+#define PASSWORD_WCP 529
+#define DONTENTERFTP_WCP 530
+#define ALWAYSSTOREPW_WCP 531
+#define INTERNALVIEWOP_WCP 532
+#define CUSTOMFILES_WCP 533
+#define SHOWMODE_WCP 534
+#define SELECTED_WCP 535
+#define REVERSESEARCH_WCP 536
+#define MOUSECONF_WCP 537
+#define SELECTBUTTON_WCP 538
+#define ACTIVATEBUTTON_WCP 539
+#define SCROLLBUTTON_WCP 540
+#define SELECTMETHOD_WCP 541
+#define ALTERNATIVE_WCP 542
+#define SEARCHOP_WCP 543
+#define EDITCOMMAND_WCP 544
+#define SHOWPREVRESULTS_WCP 545
+#define TEXTVIEW_WCP 546
+#define TEXTVIEWHIGHLIGHTED_WCP 547
+#define TEXTVIEWSELECTION_WCP 548
+#define DIRBOOKMARKOP_WCP 549
+#define OPENCONTEXTMENUOP_WCP 550
+#define RUNCUSTOMACTION_WCP 551
+#define CUSTOMNAME_WCP 552
+#define CONTEXTBUTTON_WCP 553
+#define ACTIVATEMOD_WCP 554
+#define SCROLLMOD_WCP 555
+#define CONTEXTMOD_WCP 556
+#define NONE_WCP 557
+#define CUSTOMACTION_WCP 558
+#define SAVE_WORKER_STATE_ON_EXIT_WCP 559
+#define OPENWORKERMENUOP_WCP 560
+#define CHANGELABELOP_WCP 561
+#define ASKFORLABEL_WCP 562
+#define LABELCOLORS_WCP 563
+#define BOOKMARKLABEL_WCP 564
+#define BOOKMARKFILTER_WCP 565
+#define SHOWONLYBOOKMARKS_WCP 566
+#define SHOWONLYLABEL_WCP 567
+#define SHOWALL_WCP 568
+#define OPTIONMODE_WCP 569
+#define INVERT_WCP 570
+#define SET_WCP 571
+#define CHANGEFILTERS_WCP 572
+#define CHANGEBOOKMARKS_WCP 573
+#define QUERYLABEL_WCP 574
+#define MODIFYTABSOP_WCP 575
+#define TABACTION_WCP 576
+#define NEWTAB_WCP 577
+#define CLOSECURRENTTAB_WCP 578
+#define NEXTTAB_WCP 579
+#define PREVTAB_WCP 580
+#define CHANGELAYOUTOP_WCP 581
+#define INFIXSEARCH_WCP 582
+#define ERROR 583
+#define ACTIVESIDE_WCP 584
+#define SHOWFREESPACE_WCP 585
+#define ACTIVEMODE_WCP 586
+#define ASK_WCP 587
+#define SSHALLOW_WCP 588
+#define FIELD_WIDTH_WCP 589
+#define QUICKSEARCHENABLED_WCP 590
+#define FILTEREDSEARCHENABLED_WCP 591
+#define XFTFONTS_WCP 592
+#define USEMAGIC_WCP 593
+#define MAGICPATTERN_WCP 594
+#define MAGICCOMPRESSED_WCP 595
+#define STRING_WCP 596
+#define NUM_WCP 597
 
 
 
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 210 "configparser.y"
+#line 212 "configparser.y"
 typedef union YYSTYPE {
   int num;
   char *strptr;
 } YYSTYPE;
 /* Line 1403 of yacc.c.  */
-#line 721 "configparser.tab.h"
+#line 727 "configparser.tab.h"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
