@@ -1,6 +1,6 @@
 /* execlass.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2005 Ralf Hoffmann.
+ * Copyright (C) 2002-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 /* $Id: execlass.cc,v 1.17 2005/07/13 19:56:15 ralf Exp $ */
 
@@ -399,11 +399,12 @@ typedef enum { WORKER_IS_NORMAL,
                WORKER_IS_OUTPUT_1,
                WORKER_IS_OUTPUT_2 } redirectmode_t;
 
+#if 0
 /*
  * Worker_getRedirectMode
  * THREADSAFE
  */
-int Worker_getRedirectMode( const char *str1, redirectmode_t *return_mode, int *return_filedescr, int *return_offset )
+static int Worker_getRedirectMode( const char *str1, redirectmode_t *return_mode, int *return_filedescr, int *return_offset )
 {
   redirectmode_t redirectmode;
   int j, mode, ch;
@@ -507,6 +508,7 @@ int Worker_getRedirectMode( const char *str1, redirectmode_t *return_mode, int *
   *return_mode = redirectmode;
   return 0;
 }
+#endif
 
 #if 0 //Code fuer Redirection, erlaubt im Gegensatz
       // zum aktuell benutzten Code auch Dinge wie 2>/dev/null
