@@ -1,6 +1,6 @@
 /* import.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2006 Ralf Hoffmann.
+ * Copyright (C) 2001-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "import.h"
@@ -100,10 +100,17 @@ void WConfig::setDefaultConfig()
   setLVHeader( 1, 0 );
   setStartDir(0,"");
   setStartDir(1,"");
+#ifdef HAVE_XFT
+  setFont( 0, "Sans-10" );
+  setFont( 1, "Sans-10" );
+  setFont( 2, "Sans-10" );
+  setFont( 3, "Sans-10" );
+#else
   setFont(0,"fixed");
   setFont(1,"fixed");
   setFont(2,"fixed");
   setFont(3,"fixed");
+#endif
   
   // now setup paths
   key=new WCDoubleShortkey();
