@@ -1,6 +1,6 @@
 /* informationmode.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008 Ralf Hoffmann.
+ * Copyright (C) 2001-2009 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -29,19 +29,17 @@
 #include "wcfiletype.hh"
 #include "fileentry.hh"
 #include "nmspecialsourceext.hh"
+#include <aguix/acontainer.h>
 
 const char *InformationMode::type="InformationMode";
 
 InformationMode::InformationMode(Lister *parent):ListerMode(parent)
 {
-  x=0;
-  y=0;
-  w=1;
-  h=1;
   lastactivefe=NULL;
   lv=NULL;
   blanked=false;
   nospaceinfo=false;
+  m_cont = NULL;
 }
 
 InformationMode::~InformationMode()
@@ -51,12 +49,9 @@ InformationMode::~InformationMode()
 
 void InformationMode::messageHandler(AGMessage *msg)
 {
-  int tx,ty,tw,th;
   bool ma=false;
   switch(msg->type) {
     case AG_SIZECHANGED:
-      parentlister->getGeometry(&tx,&ty,&tw,&th);
-      reconf(tx,ty,tw,th);
       break;
   }
   if(ma==true) parentlister->makeActive();
@@ -64,13 +59,17 @@ void InformationMode::messageHandler(AGMessage *msg)
 
 void InformationMode::on()
 {
-  parentlister->getGeometry(&x,&y,&w,&h);
-  if ( w < 10 ) w = 10;
-  if ( h < 10 ) h = 10;
   int side=parentlister->getSide();
   int m;
 
-  lv = (FieldListView*)parentawindow->add( new FieldListView( aguix, x, y, w, h, 1 ) );
+  m_cont = new AContainer( parentawindow, 1, 1 );
+  m_cont->setBorderWidth( 0 );
+  m_cont->setMinSpace( 0 );
+  m_cont->setMaxSpace( 0 );
+  parentlister->setContainer( m_cont );
+
+  lv = (FieldListView*)m_cont->add( new FieldListView( aguix, 0, 0, 50, 50, 1 ),
+                                    0, 0 );
   m=(wconfig->getHBarTop(side)==true)?1:2;
   lv->setHBarState(m);
   m=(wconfig->getVBarLeft(side)==true)?1:2;
@@ -89,33 +88,22 @@ void InformationMode::on()
 
   parentlister->setActiveMode(this);
   setName();
+
+  parentawindow->updateCont();
 }
 
 void InformationMode::off()
 {
-  parentawindow->remove(lv);
   delete lv;
   lv = NULL;
+  parentlister->setContainer( NULL );
+  delete m_cont;
+  m_cont = NULL;
   parentlister->setActiveMode(NULL);
   parentlister->setName("");
   clearLastActiveFE();
 }
 
-void InformationMode::reconf(int tx,int ty,int tw,int th)
-{
-  if((tw!=w)||(th!=h)||(tx!=x)||(ty!=y)) {
-    w=tw;
-    h=th;
-    if ( w < 10 ) w = 10;
-    if ( h < 10 ) h = 10;
-    x=tx;
-    y=ty;
-    lv->resize(w,h);
-    lv->move(x,y);
-    update(true);
-  }
-}
-
 void InformationMode::activate()
 {
 }
@@ -187,6 +175,8 @@ void InformationMode::setName()
 
 void InformationMode::reconfig()
 {
+    int side = parentlister->getSide();
+    lv->setFont( wconfig->getFont( 2 + side ) );
 }
 
 void InformationMode::update(bool force)
