@@ -45,6 +45,7 @@
 #include "dirbookmarkssettings.hh"
 #include "fileentry_customcolor.hh"
 #include <string>
+#include "tablookup.hh"
 
 class Lister;
 class NMFieldListViewDND;
@@ -204,7 +205,7 @@ public:
   void renamef(struct NM_renameorder *renorder);
   void dirsize(struct NM_dirsizeorder *dsorder);
   void simdd();
-  void searchentry( bool ignore_case, bool reverse_search = false );
+  void searchentry( bool ignore_case, bool reverse_search, bool infix_search );
   void enterpath();
   void scrolllister(int dir);
   void createsymlink(struct NM_createsymlinkorder *cslorder);
@@ -756,6 +757,12 @@ protected:
     } m_off_store;
 
     RefCount<TextShrinker> m_shrinker;
+    bool m_filtered_search_infix_search;
+    TabLookup m_tab_entries;
+
+    void setTabOption( int pos, const std::string &path );
+    int addTabOption( const std::string &path );
+    void removeTabOption( int pos );
 };
 
 class NMFieldListViewDND:public FieldListViewDND
