@@ -1,6 +1,6 @@
 /* ownop.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2005 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2005,2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,13 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
-/* $Id: ownop.cc,v 1.37 2005/10/19 18:03:30 ralf Exp $ */
 
 #include "ownop.h"
 #include "listermode.h"
 #include "normalmode.h"
 #include "worker.h"
 #include "filereq.h"
+#include "nmspecialsourceext.hh"
 
 const char *OwnOp::name="OwnOp";
 
