@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "scriptop.h"
@@ -152,7 +152,7 @@ ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
                 str1 += error;
                 _freesafe( reqstr );
 
-                AFontWidth lencalc( Worker::getAGUIX(), NULL );
+                RefCount<AFontWidth> lencalc( new AFontWidth( Worker::getAGUIX(), NULL ) );
                 TextStorageString ts( str1, lencalc );
 
                 Worker::getRequester()->request( catalog.getLocale( 347 ), ts, catalog.getLocale( 11 ) );
@@ -283,7 +283,7 @@ ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
                   str1 += error;
                   _freesafe( reqstr );
                   
-                  AFontWidth lencalc( Worker::getAGUIX(), NULL );
+                  RefCount<AFontWidth> lencalc( new AFontWidth( Worker::getAGUIX(), NULL ) );
                   TextStorageString ts( str1, lencalc );
                   
                   Worker::getRequester()->request( catalog.getLocale( 347 ), ts, catalog.getLocale( 11 ) );
@@ -333,7 +333,7 @@ ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
                   str1 += error;
                   _freesafe( reqstr );
                   
-                  AFontWidth lencalc( Worker::getAGUIX(), NULL );
+                  RefCount<AFontWidth> lencalc( new AFontWidth( Worker::getAGUIX(), NULL ) );
                   TextStorageString ts( str1, lencalc );
                   
                   Worker::getRequester()->request( catalog.getLocale( 347 ), ts, catalog.getLocale( 11 ) );
