@@ -1,6 +1,6 @@
 /* searchentryop.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2004,2009 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
-/* $Id: searchentryop.cc,v 1.12 2005/11/22 20:29:10 ralf Exp $ */
 
 #include "searchentryop.h"
 #include "listermode.h"
@@ -31,6 +30,7 @@ SearchEntryOp::SearchEntryOp() : FunctionProto()
 {
   ignore_case = false;
   reverse_search = false;
+  m_infix_search = false;
   hasConfigure = true;
 }
 
@@ -44,6 +44,7 @@ SearchEntryOp::duplicate() const
   SearchEntryOp *ta=new SearchEntryOp();
   ta->ignore_case = ignore_case;
   ta->reverse_search = reverse_search;
+  ta->m_infix_search = m_infix_search;
   return ta;
 }
 
@@ -94,7 +95,7 @@ SearchEntryOp::normalmodesearchentry()
   if(lm1->isType("NormalMode")!=true) return 1;
   nm1=(NormalMode*)lm1;
   
-  nm1->searchentry( ignore_case, reverse_search );
+  nm1->searchentry( ignore_case, reverse_search, m_infix_search );
   return 0;
 }
 
@@ -103,6 +104,10 @@ bool SearchEntryOp::save( Datei *fh )
   if ( fh == NULL ) return false;
   fh->configPutPairBool( "ignorecase", ignore_case );
   fh->configPutPairBool( "reversesearch", reverse_search );
+
+  if ( m_infix_search == true ) {
+      fh->configPutPairBool( "infixsearch", m_infix_search );
+  }
   return true;
 }
 
@@ -116,6 +121,11 @@ void SearchEntryOp::setReverseSearch( bool nv )
   reverse_search = nv;
 }
 
+void SearchEntryOp::setInfixSearch( bool nv )
+{
+    m_infix_search = nv;
+}
+
 int SearchEntryOp::configure()
 {
   ChooseButton *cb, *rscb;
@@ -139,7 +149,7 @@ int SearchEntryOp::configure()
   win->create();
   _freesafe( tstr );
   
-  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 4 ), true );
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
@@ -149,7 +159,11 @@ int SearchEntryOp::configure()
   rscb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( reverse_search == true ) ? 1 : 0,
 						    catalog.getLocale( 648 ), LABEL_RIGHT, 1, 0 ), 0, 1, cincwnr );
   
-  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 2 );
+  ChooseButton *iscb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, m_infix_search == true,
+                                                                  catalog.getLocale( 862 ), LABEL_RIGHT, 1, 0 ),
+                                                0, 2, AContainer::CINCWNR );
+  
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 3 );
   ac1_1->setMinSpace( 5 );
   ac1_1->setMaxSpace( -1 );
   ac1_1->setBorderWidth( 0 );
@@ -189,6 +203,7 @@ int SearchEntryOp::configure()
   if ( ende == 1 ) {
     ignore_case = cb->getState();
     reverse_search = rscb->getState();
+    m_infix_search = iscb->getState();
   }
   delete win;
   return ( ende == 1 ) ? 0 : 1;
