@@ -1,6 +1,6 @@
 /* wconfig.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2008 Ralf Hoffmann.
+ * Copyright (C) 2001-2009 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -39,6 +39,7 @@
 #include <list>
 #include "flattypelist.hh"
 #include "wckey.hh"
+#include "layoutsettings.hh"
 
 class Worker;
 class WCPath;
@@ -193,24 +194,16 @@ public:
   void clearVisCols( int side );
   void addListCol( int side, WorkerTypes::listcol_t nv );
   
-  typedef enum { LO_STATEBAR,
-                 LO_CLOCKBAR,
-                 LO_BUTTONS,
-                 LO_LISTVIEWS,
-                 LO_BLL,
-                 LO_LBL,
-                 LO_LLB,
-                 LO_BL,
-                 LO_LB,
-                 LO_DUMMY } layoutID_t;
-  void setLayoutOrders( std::list<layoutID_t> &nl );
-  std::list<layoutID_t> &getLayoutOrders();
-  void setLayoutButtonVert( bool nv );
-  bool getLayoutButtonVert() const;
-  void setLayoutListviewVert( bool nv );
-  bool getLayoutListviewVert() const;
-  void clearLayoutOrders();
-  void layoutAddEntry( layoutID_t nv );
+    void setLayoutOrders( const std::list< LayoutSettings::layoutID_t > &nl );
+    const std::list< LayoutSettings::layoutID_t > &getLayoutOrders() const;
+    void setLayoutButtonVert( bool nv );
+    bool getLayoutButtonVert() const;
+    void setLayoutListviewVert( bool nv );
+    bool getLayoutListviewVert() const;
+    void clearLayoutOrders();
+    void layoutAddEntry( LayoutSettings::layoutID_t nv );
+    void setLayoutListViewWeight( int nv );
+    int getLayoutListViewWeight() const;
 
   FlatTypeList *getFlatTypeList();
   typedef enum { MOUSECONF_NORMAL_MODE,
@@ -363,11 +356,7 @@ protected:
   List *dontcheckdirs;
   bool dontcheckvirtual;
   
-  struct {
-    std::list<layoutID_t> orders;
-    bool buttonVert;
-    bool listviewVert;
-  } layoutConf;
+    LayoutSettings m_layout_conf;
 
   struct {
     int select_button, activate_button, scroll_button, context_button;
