@@ -1,6 +1,6 @@
 /* wconfig_lang.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2006 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2006,2009 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -70,16 +70,22 @@ int LangPanel::create()
   lv->setData( trow, 0 );
   int x=1;
   if ( ( strcmp( _baseconfig.getLang(), "builtin" ) == 0 ) || ( strlen( _baseconfig.getLang() ) < 1 ) ) lv->setActiveRow( trow );
+
+#ifdef USEOWNCONFIGFILES
+  std::string ending = ".catalog2";
+#else
+  std::string ending = ".catalog";
+#endif
+  
+  if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED && UTF8::getCurrentEncoding() == UTF8::ENCODING_UTF8 ) {
+      ending += ".utf8";
+  }
+  
   if ( Worker::getDataDir().length() > 0 ) {
     catdir = Worker::getDataDir();
     catdir += "/catalogs";
     dir2 = worker_opendir( catdir.c_str() );
     if(dir2!=NULL) {
-      std::string ending = ".catalog";
-      if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED && UTF8::getCurrentEncoding() == UTF8::ENCODING_UTF8 ) {
-        ending += ".utf8";
-      }
-      
       while ( ( namelist = worker_readdir( dir2 ) ) != NULL ) {
         if ( strlen( namelist->d_name ) > ending.length() ) {
           if ( strcmp( ending.c_str(), ( namelist->d_name ) + strlen( namelist->d_name ) - ending.length() ) == 0 ) {
@@ -102,11 +108,11 @@ int LangPanel::create()
   dir2 = worker_opendir( catdir.c_str() );
   if(dir2!=NULL) {
     while ( ( namelist = worker_readdir( dir2 ) ) != NULL ) {
-      if(strlen(namelist->d_name)>8) {
-        if(strcmp(".catalog",(namelist->d_name)+strlen(namelist->d_name)-8)==0) {
+      if ( strlen( namelist->d_name ) > ending.length() ) {
+        if ( strcmp( ending.c_str(), ( namelist->d_name ) + strlen( namelist->d_name ) - ending.length() ) == 0 ) {
           // Dies ist ein Katalog
           tstr=namelist->d_name;
-          tstr[strlen(tstr)-8]=0;
+          tstr[ strlen( tstr ) - ending.length() ] = 0;
           trow = 1;
           while ( lv->isValidRow( trow ) == true ) {
             if ( strcmp( lv->getText( trow, 0 ).c_str(), tstr ) == 0 ) break;
