@@ -24,55 +24,23 @@
 #include "worker.h"
 #include <aguix/acontainerbb.h>
 #include <algorithm>
+#include <aguix/slider.h>
+#include <sstream>
 
 static struct {
-  WConfig::layoutID_t id;
+  LayoutSettings::layoutID_t id;
   int descr;
-} layoutDescr[] = { { WConfig::LO_STATEBAR, 556 },
-                    { WConfig::LO_CLOCKBAR, 557 },
-                    { WConfig::LO_BUTTONS, 558 },
-                    { WConfig::LO_LISTVIEWS, 559 },
-                    { WConfig::LO_BLL, 560 },
-                    { WConfig::LO_LBL, 561 },
-                    { WConfig::LO_LLB, 562 },
-                    { WConfig::LO_BL, 563 },
-                    { WConfig::LO_LB, 564 } };
+} layoutDescr[] = { { LayoutSettings::LO_STATEBAR, 556 },
+                    { LayoutSettings::LO_CLOCKBAR, 557 },
+                    { LayoutSettings::LO_BUTTONS, 558 },
+                    { LayoutSettings::LO_LISTVIEWS, 559 },
+                    { LayoutSettings::LO_BLL, 560 },
+                    { LayoutSettings::LO_LBL, 561 },
+                    { LayoutSettings::LO_LLB, 562 },
+                    { LayoutSettings::LO_BL, 563 },
+                    { LayoutSettings::LO_LB, 564 } };
 
-static int countID( const std::list< std::list< WConfig::layoutID_t > > &l, WConfig::layoutID_t ID )
-{
-    int count = 0;
-    for ( std::list< std::list< WConfig::layoutID_t > >::const_iterator it1 =  l.begin();
-          it1 != l.end();
-          it1++ ) {
-
-        if ( std::find( it1->begin(),
-                        it1->end(),
-                        ID ) != it1->end() ) {
-            count++;
-        }
-    }
-    return count;
-}
-
-static std::list< WConfig::layoutID_t > sanitizeUsedList( const std::list< std::list< WConfig::layoutID_t > > &avail_l,
-                                                          const std::list< WConfig::layoutID_t > &used_l )
-{
-    std::list< WConfig::layoutID_t > new_l;
-    std::map< WConfig::layoutID_t, int > count_map;
-
-    for ( std::list< WConfig::layoutID_t >::const_iterator it1 = used_l.begin();
-          it1 != used_l.end();
-          it1++ ) {
-        
-        if ( count_map[*it1] < countID( avail_l, *it1 ) ) {
-            new_l.push_back( *it1 );
-            count_map[*it1]++;
-        }
-    }
-    return new_l;
-}
-
-static std::string getDescrOfLayoutID( WConfig::layoutID_t id )
+static std::string getDescrOfLayoutID( LayoutSettings::layoutID_t id )
 {
   int s, i;
   std::string s1;
@@ -88,7 +56,7 @@ static std::string getDescrOfLayoutID( WConfig::layoutID_t id )
   return s1;
 }
 
-static WConfig::layoutID_t getLayoutIDOfDescr( const std::string &descr )
+static LayoutSettings::layoutID_t getLayoutIDOfDescr( const std::string &descr )
 {
   int s, i;
   
@@ -98,7 +66,7 @@ static WConfig::layoutID_t getLayoutIDOfDescr( const std::string &descr )
       s1 = catalog.getLocale( layoutDescr[i].descr );
       if ( s1 == descr ) return layoutDescr[i].id;
   }
-  return WConfig::LO_STATEBAR;
+  return LayoutSettings::LO_STATEBAR;
 }
 
 LayoutPanel::LayoutPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
@@ -113,85 +81,10 @@ LayoutPanel::LayoutPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel
     m_available_elements_ac = NULL;
     m_used_elements_ac = NULL;
     
-    std::list< WConfig::layoutID_t > tl;
-    {
-        std::list< std::list< WConfig::layoutID_t > > &l = m_available_elements[ std::pair< bool, bool >( false, false ) ];
-        
-        tl.clear();
-        tl.push_back( WConfig::LO_STATEBAR );
-        l.push_back( tl );
-        
-        tl.clear();
-        tl.push_back( WConfig::LO_LISTVIEWS );
-        l.push_back( tl );
-        
-        tl.clear();
-        tl.push_back( WConfig::LO_BUTTONS );
-        l.push_back( tl );
-        
-        tl.clear();
-        tl.push_back( WConfig::LO_CLOCKBAR );
-        l.push_back( tl );
-    }
-    
-    {
-        std::list< std::list< WConfig::layoutID_t > > &l = m_available_elements[ std::pair< bool, bool >( false, true ) ];
-        
-        tl.clear();
-        tl.push_back( WConfig::LO_STATEBAR );
-        l.push_back( tl );
-        
-        tl.clear();
-        tl.push_back( WConfig::LO_LISTVIEWS );
-        l.push_back( tl );
-        
-        tl.clear();
-        tl.push_back( WConfig::LO_LISTVIEWS );
-        l.push_back( tl );
-        
-        tl.clear();
-        tl.push_back( WConfig::LO_BUTTONS );
-        l.push_back( tl );
-        
-        tl.clear();
-        tl.push_back( WConfig::LO_CLOCKBAR );
-        l.push_back( tl );
-    }
-    
-    {
-        std::list< std::list< WConfig::layoutID_t > > &l = m_available_elements[ std::pair< bool, bool >( true, false ) ];
-        
-        tl.clear();
-        tl.push_back( WConfig::LO_STATEBAR );
-        l.push_back( tl );
-        
-        tl.clear();
-        tl.push_back( WConfig::LO_BLL );
-        tl.push_back( WConfig::LO_LBL );
-        tl.push_back( WConfig::LO_LLB );
-        l.push_back( tl );
-        
-        tl.clear();
-        tl.push_back( WConfig::LO_CLOCKBAR );
-        l.push_back( tl );
-    }
-    
-    {
-        std::list< std::list< WConfig::layoutID_t > > &l = m_available_elements[ std::pair< bool, bool >( true, true ) ];
-        
-        tl.clear();
-        tl.push_back( WConfig::LO_STATEBAR );
-        l.push_back( tl );
-        
-        tl.clear();
-        tl.push_back( WConfig::LO_BL );
-        tl.push_back( WConfig::LO_LB );
-        l.push_back( tl );
-        
-        tl.clear();
-        tl.push_back( WConfig::LO_CLOCKBAR );
-        l.push_back( tl );
-    }
+    m_available_elements[ std::pair< bool, bool >( false, false ) ] = LayoutSettings::getAvailableElements( false, false );
+    m_available_elements[ std::pair< bool, bool >( true, false ) ] = LayoutSettings::getAvailableElements( true, false );
+    m_available_elements[ std::pair< bool, bool >( false, true ) ] = LayoutSettings::getAvailableElements( false, true );
+    m_available_elements[ std::pair< bool, bool >( true, true ) ] = LayoutSettings::getAvailableElements( true, true );
     
     m_button_example_ac = NULL;
     m_listview_example_ac = NULL;
@@ -210,6 +103,10 @@ LayoutPanel::LayoutPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel
     m_example_clockbar_b = NULL;
     m_listview_example2_b1 = NULL;
     m_listview_example2_b2 = NULL;
+
+    m_weight_sl = NULL;
+    m_left_weight_b = NULL;
+    m_right_weight_b = NULL;
 }
 
 LayoutPanel::~LayoutPanel()
@@ -240,7 +137,7 @@ int LayoutPanel::create()
 
   int n, i;
   Text **texts;
-  std::list<WConfig::layoutID_t>::iterator it3;
+  std::list<LayoutSettings::layoutID_t>::iterator it3;
 
   bv = _baseconfig.getLayoutButtonVert();
   lvv = _baseconfig.getLayoutListviewVert();
@@ -336,6 +233,25 @@ int LayoutPanel::create()
   m_elements_example_ac1_2->setMinHeight( 10, 0, 2 );
   m_elements_example_ac1_2->setMaxHeight( 10, 0, 2 );
 
+  AContainer *weight_ac1 = ac1->add( new AContainer( this, 5, 1 ), 0, 5 );
+  weight_ac1->setMaxSpace( 5 );
+  weight_ac1->setBorderWidth( 0 );
+
+  weight_ac1->add( new Text( _aguix, 0, 0, catalog.getLocale( 861 ), 1 ), 0, 0, AContainer::CFIX );
+  m_left_weight_b = (SolidButton*)weight_ac1->add( new SolidButton( _aguix, 0, 0, "000%", 1, 0, true ),
+                                                   1, 0, AContainer::CFIX );
+  m_weight_sl = (Slider*)weight_ac1->add( new Slider( _aguix, 0, 0, 10, 10, false, 0 ),
+                                          2, 0, AContainer::CMIN );
+  m_weight_sl->setMaxLen( 8 );
+  m_weight_sl->connect( this );
+  m_right_weight_b = (SolidButton*)weight_ac1->add( new SolidButton( _aguix, 0, 0, "100%", 1, 0, true ),
+                                                    3, 0, AContainer::CFIX );
+
+  int weight = _baseconfig.getLayoutListViewWeight();
+  if ( weight < 1 || weight > 9 ) weight = 5;
+  m_weight_sl->setOffset( weight - 1 );
+  updateWeightSlider();
+
   setupElementsExample();
   setupElementsLV();
 
@@ -348,12 +264,16 @@ int LayoutPanel::saveValues()
     // Werte bernehmen
     _baseconfig.clearLayoutOrders();
 
-    m_used_elements = sanitizeUsedList( m_available_elements[ std::pair< bool, bool >( bv, lvv ) ], m_used_elements );
+    m_used_elements = LayoutSettings::fixUsedList( m_available_elements[ std::pair< bool, bool >( bv, lvv ) ], m_used_elements );
 
     _baseconfig.setLayoutOrders( m_used_elements );
     
     _baseconfig.setLayoutButtonVert( bv );
     _baseconfig.setLayoutListviewVert( lvv );
+
+    int o = m_weight_sl->getOffset();
+    o = o + 1;
+    _baseconfig.setLayoutListViewWeight( o );
     return 0;
 }
 
@@ -363,7 +283,7 @@ void LayoutPanel::run( Widget *elem, AGMessage &msg )
         if ( msg.button.button == m_add_element_b ) {
             int row = m_available_elements_lv->getActiveRow();
             if ( m_available_elements_lv->isValidRow( row ) == true ) {
-                WConfig::layoutID_t id = getLayoutIDOfDescr( m_available_elements_lv->getText( row, 0 ) );
+                LayoutSettings::layoutID_t id = getLayoutIDOfDescr( m_available_elements_lv->getText( row, 0 ) );
                 m_used_elements.push_back( id );
                 
                 setupExampleContainers();
@@ -374,7 +294,7 @@ void LayoutPanel::run( Widget *elem, AGMessage &msg )
         } else if ( msg.button.button == m_remove_element_b ) {
             int row = m_used_elements_lv->getActiveRow();
             if ( m_used_elements_lv->isValidRow( row ) == true ) {
-                std::list< WConfig::layoutID_t >::iterator it3 = m_used_elements.begin();
+                std::list< LayoutSettings::layoutID_t >::iterator it3 = m_used_elements.begin();
                 for ( ; row > 0 && it3 != m_used_elements.end(); it3++, row-- );
                 
                 if ( it3 != m_used_elements.end() ) {
@@ -391,12 +311,14 @@ void LayoutPanel::run( Widget *elem, AGMessage &msg )
         bv = cb1->getState();
         lvv = cb2->getState();
         
-        m_used_elements = sanitizeUsedList( m_available_elements[ std::pair< bool, bool >( bv, lvv ) ], m_used_elements );
+        m_used_elements = LayoutSettings::fixUsedList( m_available_elements[ std::pair< bool, bool >( bv, lvv ) ], m_used_elements );
         
         setupExampleContainers();
         setupElementsExample();
         setupElementsLV();
         contMaximize( true );
+    } else if ( msg.type == AG_SLIDER_CHANGED ) {
+        updateWeightSlider();
     }
 }
 
@@ -535,19 +457,19 @@ void LayoutPanel::setupElementsExample()
     int cur_pos = 0;
     int lv_placed = 0;
 
-    for ( std::list< WConfig::layoutID_t >::iterator it1 = m_used_elements.begin();
+    for ( std::list< LayoutSettings::layoutID_t >::iterator it1 = m_used_elements.begin();
           it1 != m_used_elements.end();
           it1++ ) {
         switch ( *it1 ) {
-            case WConfig::LO_CLOCKBAR:
+            case LayoutSettings::LO_CLOCKBAR:
                 m_elements_example_ac2->add( m_example_clockbar_b, 0, cur_pos++, AContainer::CINCW );
                 m_example_clockbar_b->show();
                 break;
-            case WConfig::LO_STATEBAR:
+            case LayoutSettings::LO_STATEBAR:
                 m_elements_example_ac2->add( m_example_statebar_b, 0, cur_pos++, AContainer::CINCW );
                 m_example_statebar_b->show();
                 break;
-            case WConfig::LO_BUTTONS:
+            case LayoutSettings::LO_BUTTONS:
                 {
                     m_button_ac = m_elements_example_ac2->add( new AContainer( this, 3, 2 ), 0, cur_pos++ );
                     m_button_ac->setBorderWidth( 0 );
@@ -567,7 +489,7 @@ void LayoutPanel::setupElementsExample()
                     }
                 }
                 break;
-            case WConfig::LO_LISTVIEWS:
+            case LayoutSettings::LO_LISTVIEWS:
                 if ( lvv == true ) {
                     if ( lv_placed == 0 ) {
                         m_listview_example2_b1->resize( 100, 20 );
@@ -595,18 +517,18 @@ void LayoutPanel::setupElementsExample()
                     m_listview_example2_b2->show();
                 }
                 break;
-            case WConfig::LO_BLL:
-            case WConfig::LO_LBL:
-            case WConfig::LO_LLB:
+            case LayoutSettings::LO_BLL:
+            case LayoutSettings::LO_LBL:
+            case LayoutSettings::LO_LLB:
                 {
                     m_lv_ac = m_elements_example_ac2->add( new AContainer( this, 3, 1 ), 0, cur_pos++ );
                     m_lv_ac->setBorderWidth( 0 );
                     m_lv_ac->setMaxSpace( 0 );
                     m_lv_ac->setMinSpace( 0 );
 
-                    if ( *it1 == WConfig::LO_BLL ) {
+                    if ( *it1 == LayoutSettings::LO_BLL ) {
                         m_button_ac = m_lv_ac->add( new AContainer( this, 1, 6 ), 0, 0 );
-                    } else if ( *it1 == WConfig::LO_LBL ) {
+                    } else if ( *it1 == LayoutSettings::LO_LBL ) {
                         m_button_ac = m_lv_ac->add( new AContainer( this, 1, 6 ), 1, 0 );
                     } else {
                         m_button_ac = m_lv_ac->add( new AContainer( this, 1, 6 ), 2, 0 );
@@ -628,10 +550,10 @@ void LayoutPanel::setupElementsExample()
                     m_listview_example2_b1->resize( 50, 40 );
                     m_listview_example2_b2->resize( 50, 40 );
 
-                    if ( *it1 == WConfig::LO_BLL ) {
+                    if ( *it1 == LayoutSettings::LO_BLL ) {
                         m_lv_ac->add( m_listview_example2_b1, 1, 0, AContainer::CMIN );
                         m_lv_ac->add( m_listview_example2_b2, 2, 0, AContainer::CMIN );
-                    } else if ( *it1 == WConfig::LO_LBL ) {
+                    } else if ( *it1 == LayoutSettings::LO_LBL ) {
                         m_lv_ac->add( m_listview_example2_b1, 0, 0, AContainer::CMIN );
                         m_lv_ac->add( m_listview_example2_b2, 2, 0, AContainer::CMIN );
                     } else {
@@ -642,15 +564,15 @@ void LayoutPanel::setupElementsExample()
                     m_listview_example2_b2->show();
                 }
                 break;
-            case WConfig::LO_BL:
-            case WConfig::LO_LB:
+            case LayoutSettings::LO_BL:
+            case LayoutSettings::LO_LB:
                 {
                     m_lv_ac = m_elements_example_ac2->add( new AContainer( this, 2, 1 ), 0, cur_pos++ );
                     m_lv_ac->setBorderWidth( 0 );
                     m_lv_ac->setMaxSpace( 0 );
                     m_lv_ac->setMinSpace( 0 );
 
-                    if ( *it1 == WConfig::LO_BL ) {
+                    if ( *it1 == LayoutSettings::LO_BL ) {
                         m_button_ac = m_lv_ac->add( new AContainer( this, 1, 6 ), 0, 0 );
                     } else {
                         m_button_ac = m_lv_ac->add( new AContainer( this, 1, 6 ), 1, 0 );
@@ -672,7 +594,7 @@ void LayoutPanel::setupElementsExample()
                     m_listview_example2_b1->resize( 100, 20 );
                     m_listview_example2_b2->resize( 100, 20 );
 
-                    if ( *it1 == WConfig::LO_BL ) {
+                    if ( *it1 == LayoutSettings::LO_BL ) {
                         m_lv2_ac = m_lv_ac->add( new AContainer( this, 1, 2 ), 1, 0 );
                     } else {
                         m_lv2_ac = m_lv_ac->add( new AContainer( this, 1, 2 ), 0, 0 );
@@ -695,34 +617,34 @@ void LayoutPanel::setupElementsExample()
 
 void LayoutPanel::setupElementsLV()
 {
-    std::map< WConfig::layoutID_t, int > count_map;
+    std::map< LayoutSettings::layoutID_t, int > count_map;
 
     m_available_elements_lv->setSize( 0 );
-    std::list< std::list< WConfig::layoutID_t > > &l = m_available_elements[ std::pair< bool, bool >( bv, lvv ) ];
-    for ( std::list< std::list< WConfig::layoutID_t > >::iterator it1 =  l.begin();
+    std::list< std::list< LayoutSettings::layoutID_t > > &l = m_available_elements[ std::pair< bool, bool >( bv, lvv ) ];
+    for ( std::list< std::list< LayoutSettings::layoutID_t > >::iterator it1 =  l.begin();
           it1 != l.end();
           it1++ ) {
 
         // if any element in *it1 is found in m_used_elements don't add it
         bool found = false;
-        for ( std::list< WConfig::layoutID_t >::iterator it2 = it1->begin();
+        for ( std::list< LayoutSettings::layoutID_t >::iterator it2 = it1->begin();
               it2 != it1->end();
               it2++ ) {
             if ( std::count( m_used_elements.begin(),
                              m_used_elements.end(),
-                             *it2 ) >= countID( l, *it2 ) ) {
+                             *it2 ) >= LayoutSettings::countID( l, *it2 ) ) {
                 found = true;
             }
         }
         
         if ( found == false ) {
-            for ( std::list< WConfig::layoutID_t >::iterator it2 = it1->begin();
+            for ( std::list< LayoutSettings::layoutID_t >::iterator it2 = it1->begin();
                   it2 != it1->end();
                   it2++ ) {
 
                 if ( count_map[*it2] + std::count( m_used_elements.begin(),
                                                    m_used_elements.end(),
-                                                   *it2 ) < countID( l, *it2 ) ) {
+                                                   *it2 ) < LayoutSettings::countID( l, *it2 ) ) {
                     int row = m_available_elements_lv->addRow();
                     m_available_elements_lv->setText( row, 0, getDescrOfLayoutID( *it2 ) );
                     m_available_elements_lv->setPreColors( row, FieldListView::PRECOLOR_ONLYACTIVE );
@@ -740,7 +662,7 @@ void LayoutPanel::setupElementsLV()
     m_available_elements_lv->redraw();
 
     m_used_elements_lv->setSize( 0 );
-    for ( std::list< WConfig::layoutID_t >::iterator it1 =  m_used_elements.begin();
+    for ( std::list< LayoutSettings::layoutID_t >::iterator it1 =  m_used_elements.begin();
           it1 != m_used_elements.end();
           it1++ ) {
         int row = m_used_elements_lv->addRow();
@@ -758,3 +680,26 @@ void LayoutPanel::setupElementsLV()
     m_available_elements_ac->readLimits();
     m_used_elements_ac->readLimits();
 }
+
+void LayoutPanel::updateWeightSlider()
+{
+    int o = m_weight_sl->getOffset();
+    o++;
+
+    o *= 10;
+    
+    {
+        std::stringstream s1;
+        s1 << o;
+        s1 << "%";
+        m_left_weight_b->setText( s1.str().c_str() );
+    }
+
+    o = 100 - o;
+    {
+        std::stringstream s1;
+        s1 << o;
+        s1 << "%";
+        m_right_weight_b->setText( s1.str().c_str() );
+    }
+}
