@@ -147,10 +147,10 @@ Worker::Worker(int targc,char **targv)
   keyhashtable = NULL;
   keyhashtable_size = 1000;
   waitcursorcount = 0;
-  restart = false;
-  configstarted = false;
+  restart = RS_NONE;
 
   m_interpret_recursion_depth = 0;
+  m_use_custom_layout = false;
 }
 
 Worker::~Worker()
@@ -187,8 +187,7 @@ void Worker::run()
   time_t lastConfig = 0;
   std::string str1;
 
-  restart = false;
-  configstarted = false;
+  restart = RS_NONE;
   wconfig->loadsize(&w,&h);
   if ( w < 300 ) w = 300;
   if ( h < 200 ) h = 200;
@@ -339,6 +338,7 @@ void Worker::run()
       aguix->ReplyMessage(msg);
     } else {
       updateTime();
+      updateStatebar();
       lister[0]->cyclicfunc(CYCLICFUNC_MODE_NORMAL);
       lister[1]->cyclicfunc(CYCLICFUNC_MODE_NORMAL);
       waitcount++;
@@ -359,8 +359,7 @@ void Worker::run()
               wconfig->load();
               wconfig->applyColorList(wconfig->getColors());
               wconfig->applyLanguage();
-              configstarted = true;
-              restart = true;
+              restart = RS_RECONFIG;
             }
             lastConfig = wconfig->getFileConfigMod();
           }
@@ -369,27 +368,26 @@ void Worker::run()
       }
       waittime(20);
     }
-    if(configstarted==true) {
-      if(restart==false) {
+
+    if ( restart == RS_RECONFIG ) {
+        buildtable();
+
+        //TODO
+        aguix->setFont(wconfig->getFont(0));
+        setupMainWin();
+        rows=wconfig->getRows();
+        columns=wconfig->getColumns();
+        lister[0]->reconfig();
+        lister[1]->reconfig();
         lister[0]->cyclicfunc(CYCLICFUNC_MODE_RESTART);
         lister[1]->cyclicfunc(CYCLICFUNC_MODE_RESTART);
-      }
-      configstarted=false;
-      buildtable();
-    }
-    if(restart==true) {
-      //TODO
-      aguix->setFont(wconfig->getFont(0));
-      setupMainWin();
-      rows=wconfig->getRows();
-      columns=wconfig->getColumns();
-      lister[0]->reconfig();
-      lister[1]->reconfig();
-      lister[0]->cyclicfunc(CYCLICFUNC_MODE_RESTART);
-      lister[1]->cyclicfunc(CYCLICFUNC_MODE_RESTART);
-      restart=false;
-      lasttimep=0;
+        lasttimep=0;
+    } else if ( restart == RS_RELAYOUT ) {
+        setupMainWin();
+        lister[0]->reconfig();
+        lister[1]->reconfig();
     }
+    restart = RS_NONE;
   }
 
   if ( wconfig->getSaveWorkerStateOnExit() == true ) {
@@ -515,8 +513,8 @@ void Worker::setupMainWin()
                      AContainer::ACONT_MAXH;
   bool bv, lvv, statebarfound;
   int e1, pos;
-  std::list<WConfig::layoutID_t> orders;
-  std::list<WConfig::layoutID_t>::iterator it1;
+  std::list<LayoutSettings::layoutID_t> orders;
+  std::list<LayoutSettings::layoutID_t>::iterator it1;
   AContainer *sbc = NULL;
   AContainer *clbc = NULL;
   AContainer *bc = NULL;
@@ -526,23 +524,35 @@ void Worker::setupMainWin()
   int x,y;
   int statebarCount, clockbarCount, buttonsCount, bllCount, blCount;
   int l;
+  int lv_weight[2] = { 5, 5 };
   
   rows=wconfig->getRows();
   columns=wconfig->getColumns();
 
   if ( maincont != NULL ) delete maincont;
   
-  bv = wconfig->getLayoutButtonVert();
-  lvv = wconfig->getLayoutListviewVert();
-  orders = wconfig->getLayoutOrders();
+  if ( m_use_custom_layout == true ) {
+      bv = m_custom_layout.getButtonVert();
+      lvv = m_custom_layout.getListViewVert();
+      orders = m_custom_layout.getOrders();
+      lv_weight[0] = m_custom_layout.getListViewWeight();
+  } else {
+      bv = wconfig->getLayoutButtonVert();
+      lvv = wconfig->getLayoutListviewVert();
+      orders = wconfig->getLayoutOrders();
+      lv_weight[0] = wconfig->getLayoutListViewWeight();
+  }
+
+  if ( lv_weight[0] < 1 || lv_weight[0] > 9 ) lv_weight[0] = 5;
+  lv_weight[1] = 10 - lv_weight[0];
   
   if ( orders.size() < 1 ) {
     // default values for empty orders
     bv = lvv = false;
-    orders.push_back( WConfig::LO_STATEBAR );
-    orders.push_back( WConfig::LO_LISTVIEWS );
-    orders.push_back( WConfig::LO_BUTTONS );
-    orders.push_back( WConfig::LO_CLOCKBAR );
+    orders.push_back( LayoutSettings::LO_STATEBAR );
+    orders.push_back( LayoutSettings::LO_LISTVIEWS );
+    orders.push_back( LayoutSettings::LO_BUTTONS );
+    orders.push_back( LayoutSettings::LO_CLOCKBAR );
   }
   
   if ( ( bv == true ) && ( lvv == true ) ) e1 = 3;
@@ -555,7 +565,7 @@ void Worker::setupMainWin()
   
   statebarfound = false;
   for ( it1 = orders.begin(); it1 != orders.end(); it1++ ) {
-    if ( *it1 == WConfig::LO_STATEBAR ) {
+    if ( *it1 == LayoutSettings::LO_STATEBAR ) {
       statebarfound = true;
       break;
     }
@@ -574,7 +584,7 @@ void Worker::setupMainWin()
   blCount = 0;
   for ( pos = 0, it1 = orders.begin(); ( pos < e1 ) && ( it1 != orders.end() ); pos++ ) {
     if ( ( statebarfound == false ) ||
-         ( *it1 == WConfig::LO_STATEBAR ) ) {
+         ( *it1 == LayoutSettings::LO_STATEBAR ) ) {
       if ( statebarCount < 1 ) {
         sbc = maincont->add( new AContainer( mainwin, 3, 1 ), 0, pos );
         sbc->setMaxSpace( 0 );
@@ -590,7 +600,7 @@ void Worker::setupMainWin()
           continue;
         }
       }
-    } else if ( *it1 == WConfig::LO_CLOCKBAR ) {
+    } else if ( *it1 == LayoutSettings::LO_CLOCKBAR ) {
       if ( clockbarCount < 1 ) {
         clbc = maincont->add( new AContainer( mainwin, 1, 1 ), 0, pos );
         clbc->setMaxSpace( 0 );
@@ -599,7 +609,7 @@ void Worker::setupMainWin()
         clbc->add( clockbar, 0, 0, conlyh );
         clockbarCount++;
       }
-    } else if ( *it1 == WConfig::LO_BUTTONS ) {
+    } else if ( *it1 == LayoutSettings::LO_BUTTONS ) {
       if ( ( bv == false ) && ( buttonsCount < 1 ) ) {
         bc = maincont->add( new AContainer( mainwin, columns + 1, rows ), 0, pos );
         bc->setMaxSpace( 0 );
@@ -607,7 +617,7 @@ void Worker::setupMainWin()
         bc->setBorderWidth( 0 );
         buttonsCount++;
       }
-    } else if ( *it1 == WConfig::LO_LISTVIEWS ) {
+    } else if ( *it1 == LayoutSettings::LO_LISTVIEWS ) {
       if ( bv == false ) {
         if ( ( listviewsCount < 1 ) && ( lvv == false ) ) {
           lc = maincont->add( new AContainer( mainwin, 2, 1 ), 0, pos );
@@ -615,7 +625,9 @@ void Worker::setupMainWin()
           lc->setMinSpace( 0 );
           lc->setBorderWidth( 0 );
           lc->add( listerwin[0], 0, 0 );
+          lc->setWWeight( lv_weight[0], 0, 0 );
           lc->add( listerwin[1], 1, 0 );
+          lc->setWWeight( lv_weight[1], 1, 0 );
           listviewsCount++;
         } else if ( ( listviewsCount < 2 ) && ( lvv == true ) ) {
           lc = maincont->add( new AContainer( mainwin, 1, 1 ), 0, pos );
@@ -623,10 +635,11 @@ void Worker::setupMainWin()
           lc->setMinSpace( 0 );
           lc->setBorderWidth( 0 );
           lc->add( listerwin[listviewsCount], 0, 0 );
+          maincont->setHWeight( lv_weight[listviewsCount], 0, pos );
           listviewsCount++;
         }
       }
-    } else if ( *it1 == WConfig::LO_BLL ) {
+    } else if ( *it1 == LayoutSettings::LO_BLL ) {
       if ( ( bv == true ) && ( lvv == false ) && ( bllCount < 1 ) ) {
         lc = maincont->add( new AContainer( mainwin, 3, 1 ), 0, pos );
         lc->setMaxSpace( 0 );
@@ -641,13 +654,15 @@ void Worker::setupMainWin()
         bc->setBorderWidth( 0 );
         bllCount++;
         
-        lc->setWWeight( 2, 1, 0 );
-        lc->setWWeight( 2, 2, 0 );
+        lc->setWWeight( 2 * lv_weight[0], 1, 0 );
+        lc->setWWeight( 2 * lv_weight[1], 2, 0 );
+
+        lc->setWWeight( 1 * 5, 0, 0 );
 
         l = getMaxButtonsWidth() + 4;
         lc->setMaxWidth( l, 0, 0 );
       }
-    } else if ( *it1 == WConfig::LO_LBL ) {
+    } else if ( *it1 == LayoutSettings::LO_LBL ) {
       if ( ( bv == true ) && ( lvv == false ) && ( bllCount < 1 ) ) {
         lc = maincont->add( new AContainer( mainwin, 3, 1 ), 0, pos );
         lc->setMaxSpace( 0 );
@@ -662,13 +677,15 @@ void Worker::setupMainWin()
         bc->setBorderWidth( 0 );
         bllCount++;
         
-        lc->setWWeight( 2, 0, 0 );
-        lc->setWWeight( 2, 2, 0 );
+        lc->setWWeight( 2 * lv_weight[0], 0, 0 );
+        lc->setWWeight( 2 * lv_weight[1], 2, 0 );
+
+        lc->setWWeight( 1 * 5, 1, 0 );
 
         l = getMaxButtonsWidth() + 4;
         lc->setMaxWidth( l, 1, 0 );
       }
-    } else if ( *it1 == WConfig::LO_LLB ) {
+    } else if ( *it1 == LayoutSettings::LO_LLB ) {
       if ( ( bv == true ) && ( lvv == false ) && ( bllCount < 1 ) ) {
         lc = maincont->add( new AContainer( mainwin, 3, 1 ), 0, pos );
         lc->setMaxSpace( 0 );
@@ -683,13 +700,15 @@ void Worker::setupMainWin()
         bc->setBorderWidth( 0 );
         bllCount++;
         
-        lc->setWWeight( 2, 0, 0 );
-        lc->setWWeight( 2, 1, 0 );
+        lc->setWWeight( 2 * lv_weight[0], 0, 0 );
+        lc->setWWeight( 2 * lv_weight[1], 1, 0 );
+
+        lc->setWWeight( 1 * 5, 2, 0 );
 
         l = getMaxButtonsWidth() + 4;
         lc->setMaxWidth( l, 2, 0 );
       }
-    } else if ( *it1 == WConfig::LO_BL ) {
+    } else if ( *it1 == LayoutSettings::LO_BL ) {
       if ( ( bv == true ) && ( lvv == true ) && ( blCount < 1 ) ) {
         lc = maincont->add( new AContainer( mainwin, 2, 1 ), 0, pos );
         lc->setMaxSpace( 0 );
@@ -700,7 +719,9 @@ void Worker::setupMainWin()
         lc2->setMinSpace( 0 );
         lc2->setBorderWidth( 0 );
         lc2->add( listerwin[0], 0, 0 );
+        lc2->setHWeight( lv_weight[0], 0, 0 );
         lc2->add( listerwin[1], 0, 1 );
+        lc2->setHWeight( lv_weight[1], 0, 1 );
         
         bc = lc->add( new AContainer( mainwin, 1 , ( columns + 1 ) * rows ), 0, 0 );
         bc->setMaxSpace( 0 );
@@ -712,7 +733,7 @@ void Worker::setupMainWin()
         l = getMaxButtonsWidth() + 4;
         lc->setMaxWidth( l, 0, 0 );
       }
-    } else if ( *it1 == WConfig::LO_LB ) {
+    } else if ( *it1 == LayoutSettings::LO_LB ) {
       if ( ( bv == true ) && ( lvv == true ) && ( blCount < 1 ) ) {
         lc = maincont->add( new AContainer( mainwin, 2, 1 ), 0, pos );
         lc->setMaxSpace( 0 );
@@ -723,7 +744,9 @@ void Worker::setupMainWin()
         lc2->setMinSpace( 0 );
         lc2->setBorderWidth( 0 );
         lc2->add( listerwin[0], 0, 0 );
+        lc2->setHWeight( lv_weight[0], 0, 0 );
         lc2->add( listerwin[1], 0, 1 );
+        lc2->setHWeight( lv_weight[1], 0, 1 );
         
         bc = lc->add( new AContainer( mainwin, 1, ( columns + 1 ) * rows ), 1, 0 );
         bc->setMaxSpace( 0 );
@@ -870,19 +893,10 @@ void Worker::setupMainWin()
 
 void Worker::setStatebarText(const char *str)
 {
-  if ( statebar != NULL ) {
-    statebar->setText( 0, str );
-    last_statebar_text[0] = last_statebar_text[1];
-    last_statebar_text[1] = str;
-  }
-}
-
-void Worker::resetStatebarText()
-{
-  std::string str1;
-
-  str1 = last_statebar_text[0];
-  setStatebarText( str1.c_str() );
+    if ( statebar != NULL ) {
+        m_statebar_text = str;
+        updateStatebar();
+    }
 }
 
 void Worker::shufflePath()
@@ -1090,8 +1104,9 @@ bool Worker::configure()
   setStatebarText( oldsbt.c_str() );
   unsetWaitCursor();
 
-  restart = erg;
-  configstarted = true;
+  // set restart to RECONFIG even of configure was canceled
+  // some caches might be invalid
+  restart = RS_RECONFIG;
 
   return erg;
 }
@@ -1225,7 +1240,7 @@ int Worker::activateShortkey(AGMessage *msg)
   WCButton *b1;
   WCPath *p1;
   ActionMessage amsg( this );
-  bool found;
+  bool found, keychain_cand = false;
   if((msg->type==AG_KEYPRESSED)||(msg->type==AG_KEYRELEASED)) {
 
       amsg.setKeyAction( true );
@@ -1295,8 +1310,36 @@ int Worker::activateShortkey(AGMessage *msg)
             lastkey = msg->key.key;
             lastmod = keystate;
             lastkey_time = msg->key.time;
+
+            if ( isKeyChainPrefix( msg->key.key, keystate ) == true ) {
+                keychain_cand = true;
+            }
         }
     }
+
+    if ( found == true ) {
+        removeStatebarText( m_key_message );
+    } else if ( keychain_cand == true ) {
+        char *tstr = aguix->getNameOfKey( msg->key.key, keystate );
+        std::string key_info;
+        if ( tstr != NULL ) {
+            key_info = tstr;
+            _freesafe( tstr );
+        } else {
+            key_info = "???";
+        }
+        key_info += " [ ";
+        key_info += getNamesOfKeyChainCompletions( msg->key.key, keystate );
+        key_info += " ]";
+        removeStatebarText( m_key_message );
+        m_key_message = TimedText( key_info,
+                                   time( NULL ) + 1,
+                                   time( NULL ) + 61 );
+        updateStatebarText( m_key_message );
+    } else {
+        removeStatebarText( m_key_message );
+    }
+
     return ( found == true ) ? 1 : 0;
   }
   return 0;
@@ -2394,6 +2437,40 @@ int Worker::findkey( KeySym k1, unsigned int m1, KeySym k2, unsigned int m2, WCB
   return returnvalue;
 }
 
+bool Worker::isKeyChainPrefix( KeySym k, unsigned int m )
+{
+    unsigned int hashvalue;
+    keyhash *kh;
+    bool hit = false;
+
+    if ( k == 0 ) return false;
+    if ( keyhashtable == NULL ) return false;
+    
+    hashvalue = keyhashfunc( k, m );
+    kh = keyhashtable[ hashvalue ];
+    
+    while ( kh != NULL ) {
+        if ( kh->b != NULL ) {
+            if ( kh->b->isKeyChainPrefix( k, m ) == true ) {
+                hit = true;
+                break;
+            }
+        } else if ( kh->h != NULL ) {
+            if ( kh->h->isKeyChainPrefix( k, m ) == true ) {
+                hit = true;
+                break;
+            }
+        } else if ( kh->p != NULL ) {
+            if ( kh->p->isKeyChainPrefix( k, m ) == true ) {
+                hit = true;
+                break;
+            }
+        }
+        kh = kh->next;
+    }
+    return hit;
+}
+
 void Worker::closeMainWin()
 {
   unsigned int i, j;
@@ -2716,6 +2793,10 @@ int Worker::runCommand( const char*exestr,
   child = fork();
   if ( child != 0 ) {
     // parent
+
+    TimedText temp_sbtext( catalog.getLocale( 547 ),
+                           time( NULL ) );
+    
     if ( child == -1 ) {
       unsetWaitCursor();
       return -2;
@@ -2725,7 +2806,7 @@ int Worker::runCommand( const char*exestr,
     aguix->getLastKeyRelease();
     aguix->getLastMouseRelease();
     if ( inbackground == false ) {
-      setStatebarText( catalog.getLocale( 547 ) );
+        pushStatebarText( temp_sbtext );
     }
     // after setting this flag Worker won't read/write from the pipe
     // because the child is expected to exit right after this
@@ -2774,7 +2855,7 @@ int Worker::runCommand( const char*exestr,
     }
     unsetWaitCursor();
     if ( inbackground == false ) {
-      resetStatebarText();
+        removeStatebarText( temp_sbtext );
     }
     return retval;
   }
@@ -3161,3 +3242,192 @@ void Worker::handlePopUps( AGMessage *msg )
         }
     }
 }
+
+LayoutSettings Worker::getCustomLayout() const
+{
+    return m_custom_layout;
+}
+
+bool Worker::getUseCustomLayout() const
+{
+    return m_use_custom_layout;
+}
+
+void Worker::setCustomLayout( const LayoutSettings &nv )
+{
+    m_use_custom_layout = true;
+    m_custom_layout = nv;
+    restart = RS_RELAYOUT;
+}
+
+void Worker::unsetCustomLayout()
+{
+    m_use_custom_layout = false;
+    restart = RS_RELAYOUT;
+}
+
+void Worker::pushStatebarText( const TimedText &text )
+{
+    std::list< TimedText >::iterator it1 = m_statebar_texts.begin();
+
+    for ( ;
+          it1 != m_statebar_texts.end();
+          it1++ ) {
+        if ( text.isOlder( *it1 ) )
+            break;
+    }
+    m_statebar_texts.insert( it1, text );
+
+    updateStatebar();
+}
+
+bool Worker::getValidStatebarText( TimedText &return_text )
+{
+    std::list< TimedText >::iterator it1 = m_statebar_texts.begin();
+    time_t now = time( NULL );
+
+    // first remove all expired texts
+    while ( it1 != m_statebar_texts.end() ) {
+        if ( it1->isExpired( now ) == true ) {
+            std::list< TimedText >::iterator it2 = it1;
+            it1++;
+
+            m_statebar_texts.erase( it2 );
+        } else {
+            it1++;
+        }
+    }
+
+    // now find the youngest valid entry
+    std::list< TimedText >::iterator cand = m_statebar_texts.end();
+
+    it1 = m_statebar_texts.begin();
+    while ( it1 != m_statebar_texts.end() ) {
+        if ( it1->isValid( now ) == true ) {
+            cand = it1;
+        } else {
+            break;
+        }
+        it1++;
+    }
+
+    if ( cand != m_statebar_texts.end() ) {
+        return_text = *cand;
+        return true;
+    } else {
+        return false;
+    }
+}
+
+void Worker::updateStatebarText( const TimedText &text )
+{
+    std::list< TimedText >::iterator it1 = m_statebar_texts.begin();
+    bool found = false;
+
+    for ( ;
+          it1 != m_statebar_texts.end();
+          it1++ ) {
+        if ( it1->getValidAt() == text.getValidAt() &&
+             it1->getExpireAt() == text.getExpireAt() ) {
+            *it1 = text;
+
+            updateStatebar();
+            found = true;
+            break;
+        }
+    }
+
+    if ( found == false ) {
+        pushStatebarText( text );
+    }
+}
+
+void Worker::removeStatebarText( const TimedText &text )
+{
+    std::list< TimedText >::iterator it1 = m_statebar_texts.begin();
+
+    for ( ;
+          it1 != m_statebar_texts.end();
+          it1++ ) {
+        if ( it1->getValidAt() == text.getValidAt() &&
+             it1->getExpireAt() == text.getExpireAt() ) {
+            m_statebar_texts.erase( it1 );
+
+            updateStatebar();
+            break;
+        }
+    }
+}
+
+void Worker::updateStatebar()
+{
+    TimedText t;
+    std::string text;
+
+    if ( statebar == NULL ) return;
+
+    if ( getValidStatebarText( t ) == true ) {
+        text = t.getText();
+    } else {
+        text = m_statebar_text;
+    }
+    if ( text != statebar->getText( 0 ) ) {
+        statebar->setText( 0, text.c_str() );
+    }
+}
+
+std::string Worker::getNamesOfKeyChainCompletions( KeySym k, unsigned int m )
+{
+    unsigned int hashvalue;
+    keyhash *kh;
+    std::string res;
+    int id_dk;
+    List *dkeys;
+    WCDoubleShortkey *dk;
+    
+    if ( k == 0 ) return "";
+    if ( keyhashtable == NULL ) return "";
+  
+    hashvalue = keyhashfunc( k, m );
+    kh = keyhashtable[ hashvalue ];
+
+    if ( kh != NULL ) {
+        while ( kh != NULL ) {
+            dkeys = NULL;
+            if ( kh->b != NULL ) {
+                dkeys = kh->b->getDoubleKeys();
+            } else if ( kh->h != NULL ) {
+                dkeys = kh->h->getDoubleKeys();
+            } else if ( kh->p != NULL ) {
+                dkeys = kh->p->getDoubleKeys();
+            }
+
+            if ( dkeys != NULL ) {
+                id_dk = dkeys->initEnum();
+                dk = (WCDoubleShortkey*)dkeys->getFirstElement( id_dk );
+                while ( dk != NULL ) {
+                    if ( dk->getType() == WCDoubleShortkey::WCDS_DOUBLE &&
+                         dk->getKeySym( 0 ) == k &&
+                         dk->getMod( 0 ) == m ) {
+                        char *tstr = aguix->getNameOfKey( dk->getKeySym( 1 ),
+                                                          dk->getMod( 1 ) );
+                        if ( tstr != NULL ) {
+                            if ( ! res.empty() ) {
+                                res += " , ";
+                            }
+                            res += tstr;
+                            _freesafe( tstr );
+                        }
+                    }
+                    
+                    dk = (WCDoubleShortkey*)dkeys->getNextElement( id_dk );
+                }
+                dkeys->closeEnum( id_dk );
+            }
+
+            kh = kh->next;
+        }
+    }
+    
+    return res;
+}
