@@ -1,6 +1,6 @@
 /* worker.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2008 Ralf Hoffmann.
+ * Copyright (C) 2001-2009 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -37,6 +37,8 @@
 #include <aguix/acontainer.h>
 #include <string>
 #include "generic_callback.hh"
+#include "layoutsettings.hh"
+#include "timedtext.hh"
 
 class ListerMode;
 class Lister;
@@ -61,7 +63,6 @@ public:
   ListerMode *getMode4ID(int,Lister *);
   AWindow *getMainWin();
   void setStatebarText(const char*);
-  void resetStatebarText();
   static int getNrOfCommands();
   FunctionProto *getCommand4ID(int);
   static int getID4Command(FunctionProto*);
@@ -109,6 +110,16 @@ public:
   void registerPopUpCallback( RefCount<GenericCallbackArg<void, AGMessage*> > cb,
                               const PopUpMenu *menu );
   void unregisterPopUpCallback( RefCount<GenericCallbackArg<void, AGMessage*> > cb );
+
+  LayoutSettings getCustomLayout() const;
+  bool getUseCustomLayout() const;
+  void setCustomLayout( const LayoutSettings &nv );
+  void unsetCustomLayout();
+
+    void pushStatebarText( const TimedText &text );
+    void updateStatebarText( const TimedText &text );
+    void removeStatebarText( const TimedText &text );
+
  protected:
   void createMainWin();
   void setupMainWin();
@@ -179,14 +190,12 @@ public:
   void insertkey( KeySym k, unsigned int m, WCButton *b, WCHotkey *h, WCPath *p );
   int findkey( KeySym k, unsigned int m, WCButton **b, WCHotkey **h, WCPath **p );
   int findkey( KeySym k1, unsigned int m1, KeySym k2, unsigned int m2, WCButton **b, WCHotkey **h, WCPath **p );
+  bool isKeyChainPrefix( KeySym k, unsigned int m );
   int waitcursorcount;
   
   int getMaxButtonsWidth();
 
-  bool restart;
-  bool configstarted;
-
-  std::string last_statebar_text[2];
+  std::string m_statebar_text;
 
   std::string queryLanguage();
 
@@ -203,7 +212,27 @@ public:
   std::map<const PopUpMenu *, std::list< RefCount<GenericCallbackArg<void, AGMessage*> > > > m_popup_callbacks;
 
   void handlePopUps( AGMessage *msg );
+
+  bool m_use_custom_layout;
+  LayoutSettings m_custom_layout;
+
+    typedef enum {
+        RS_RECONFIG,
+        RS_RELAYOUT,
+        RS_NONE
+    } restart_t;
+    restart_t restart;
+
+    std::list< TimedText > m_statebar_texts;
+    bool getValidStatebarText( TimedText &return_text );
+    void updateStatebar();
+
+    TimedText m_key_message;
+    std::string getNamesOfKeyChainCompletions( KeySym k, unsigned int m );
 };
 
 #endif
 
+/* Local Variables: */
+/* mode:c++ */
+/* End: */
