@@ -195,6 +195,9 @@ FunctionProto *Worker::getCommand4ID(int id)
     case 56:
       fpr = new ModifyTabsOp();
       break;
+    case 57:
+      fpr = new ChangeLayoutOp();
+      break;
     default:
       fpr=new DNDAction();
   }
@@ -261,6 +264,7 @@ int Worker::getID4Command(FunctionProto *fpr)
   else if ( fpr->isName( OpenWorkerMenuOp::name ) == true ) type = 54;
   else if ( fpr->isName( ChangeLabelOp::name ) == true ) type = 55;
   else if ( fpr->isName( ModifyTabsOp::name ) == true ) type = 56;
+  else if ( fpr->isName( ChangeLayoutOp::name ) == true ) type = 57;
   return type;
 }
 
