@@ -59,6 +59,8 @@
 #include "openworkermenuop.hh"
 #include "changelabelop.hh"
 #include "modifytabsop.hh"
+#include "changelayoutop.hh"
+#include "enterdirop.hh"
 
 #include "listermode.h"
 #include "normalmode.h"
