@@ -24,8 +24,8 @@
 #include "worker.h"
 #include <aguix/utf8.hh>
 
-#define CATENTRY 861
-#define CATCOMENTRY 57
+#define CATENTRY 863
+#define CATCOMENTRY 58
 #define CATFLAGENTRY 59
 
 WorkerLocale catalog;
@@ -960,6 +960,8 @@ match any font." );
   catalog[858]=dupstring( "Used elements:" );
   catalog[859]=dupstring( "Add element" );
   catalog[860]=dupstring( "Remove element" );
+  catalog[861]=dupstring( "List view weight:" );
+  catalog[862]=dupstring( "Match inside file name (implicit leading *)" );
 
 //  catalog[]=dupstring( "" );
   
@@ -1020,6 +1022,7 @@ match any font." );
   catalogcom[54]=dupstring( "Open Worker menu" );
   catalogcom[55]=dupstring( "Change file label" );
   catalogcom[56]=dupstring( "Modify tabs" );
+  catalogcom[57]=dupstring( "Change layout" );
   
   catalogflag[0]=dupstring( "Stringrequester" );
   catalogflag[1]=dupstring( "path" );
